# $Id: pybaux.py,v 1.10 2009/08/19 10:02:32 jhh Exp $
#
# Author: Jaap-Henk Hoepman (jhh@xs4all.nl)
#
# Functions to parse LaTeX aux files
#
# Adapted to python3

import os, re

# regular expression to match in the .aux file
citation_re = re.compile ('\\citation\{([^\}]+)\}')
include_re  = re.compile ('^\\\@input\{([^\}]+)\}')

# Return the citation keys found in auxfile 'file' as a set of strings
# (so no duplicates). Recurse through any aux files included through
# the @input macro
def get_citations(file):
    citations = set()
    # make sure the auxname has the .aux suffix (it will not when read as
    # @input entry from an aux file)
    auxname = os.path.splitext (file) [0] + '.aux'
    # open the aux file; return the empty set if that fails
    with open(auxname,'r') as auxf:
        for line in auxf.readlines():
            # remove whitesapce
            line.strip()
            # check if we have to include an additional .aux file
            match = include_re.search (line)
            if match:
                # if so then recure and add the results
                citations |= get_citations(match.group (1))
            else:
                # otherwise, check for a \citation and add the citation keys
                match = citation_re.search (line)
                if match:
                    keys = match.group(1)
                    # citation may contain multiple keys, separated by a comma
                    citations |=  set( keys.split(",") )
    return citations

            
